@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2010 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdaudioimport.cpp,v 1.12 2011/12/23 23:07:00 cvs Exp $
+//      $Id: rdaudioimport.cpp,v 1.12.4.4 2014/01/15 19:56:32 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -22,6 +22,7 @@
 
 #include <stdlib.h>
 #include <stdio.h>
+#include <syslog.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
@@ -63,11 +64,12 @@ int ImportProgressCallback(void *clientp,double dltotal,double dlnow,
 }
 
 
-RDAudioImport::RDAudioImport(RDStation *station,
+RDAudioImport::RDAudioImport(RDStation *station,RDConfig *config,
 			     QObject *parent,const char *name)
   : QObject(parent,name)
 {
   conv_station=station;
+  conv_config=config;
   conv_cart_number=0;
   conv_cut_number=0;
   conv_settings=NULL;
@@ -112,10 +114,10 @@ RDAudioImport::ErrorCode RDAudioImport::runImport(const QString &username,
 {
   long response_code;
   CURL *curl=NULL;
+  CURLcode curl_err;
   struct curl_httppost *first=NULL;
   struct curl_httppost *last=NULL;
   char url[1024];
-  char str[1024];
   QString xml;
   RDWebResult web_result;
 
@@ -180,13 +182,13 @@ RDAudioImport::ErrorCode RDAudioImport::runImport(const QString &username,
   // otherwise some versions of LibCurl will throw a 'bad/illegal format' 
   // error.
   //
-  strncpy(url,conv_station->webServiceUrl(),1024);
+  strncpy(url,conv_station->webServiceUrl(conv_config),1024);
   curl_easy_setopt(curl,CURLOPT_URL,url);
 
   //
   // Send it
   //
-  switch(curl_easy_perform(curl)) {
+  switch(curl_err=curl_easy_perform(curl)) {
   case CURLE_OK:
     break;
 
@@ -204,6 +206,7 @@ RDAudioImport::ErrorCode RDAudioImport::runImport(const QString &username,
   case CURLE_OPERATION_TIMEDOUT:
   case CURLE_HTTP_POST_ERROR:
     curl_easy_cleanup(curl);
+  default:
     return RDAudioImport::ErrorInternal;
 
   case CURLE_URL_MALFORMAT:
@@ -213,6 +216,10 @@ RDAudioImport::ErrorCode RDAudioImport::runImport(const QString &username,
     curl_easy_cleanup(curl);
     return RDAudioImport::ErrorUrlInvalid;
   }
+  /*
+    syslog(LOG_NOTICE,"CURL code: %d [%s]\n",curl_err,
+    curl_easy_strerror(curl_err));
+  */
 
   //
   // Clean up
@@ -230,6 +237,7 @@ RDAudioImport::ErrorCode RDAudioImport::runImport(const QString &username,
   else {
     *conv_err=RDAudioConvert::ErrorOk;
   }
+  //printf("resp code: %d\n",response_code);
   switch(response_code) {
   case 200:
     break;
