@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdbutton_dialog.cpp,v 1.18 2007/12/31 18:49:08 fredg Exp $
+//      $Id: rdbutton_dialog.cpp,v 1.23.6.1.2.1 2014/03/21 15:41:44 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -28,7 +28,7 @@
 #include <rdcart_dialog.h>
 #include <rd.h>
 #include <rdbutton_dialog.h>
-
+#include <rdconf.h>
 
 RDButtonDialog::RDButtonDialog(QString station_name,
 			       const QString &label_template,
@@ -151,13 +151,18 @@ QSizePolicy RDButtonDialog::sizePolicy() const
 }
 
 
-int RDButtonDialog::exec(RDPanelButton *button,bool hookmode)
+int RDButtonDialog::exec(RDPanelButton *button,bool hookmode,
+			 const QString &username,const QString &passwd)
 {
   edit_button=button;
   edit_hookmode=hookmode;
+  edit_user_name=username;
+  edit_user_password=passwd;
   edit_cart=edit_button->cart();
   edit_color=edit_button->defaultColor();
-  edit_color_button->setPalette(QPalette(edit_color,backgroundColor()));
+  QPalette p=QPalette(edit_color,backgroundColor());
+  p.setColor(QColorGroup::ButtonText,RDGetTextColor(edit_color));
+  edit_color_button->setPalette(p);
   edit_label_edit->setText(edit_button->text());
   DisplayCart(edit_cart);
   return QDialog::exec();
@@ -166,21 +171,8 @@ int RDButtonDialog::exec(RDPanelButton *button,bool hookmode)
 
 void RDButtonDialog::setCartData()
 {
-  QString svc_name[RD_MAX_DEFAULT_SERVICES];
-  QString sql;
-  RDSqlQuery *q;
-  int svc_quan=0;
-
-  sql=QString().sprintf("select SERVICE_NAME from SERVICE_PERMS\
-                                 where STATION_NAME=\"%s\"",
-			(const char *)edit_station_name);
-  q=new RDSqlQuery(sql);
-  while(q->next()&&svc_quan<(RD_MAX_DEFAULT_SERVICES-1)) {
-    svc_name[svc_quan++]=q->value(0).toString();
-  }
-  delete q;
-
-  if(edit_cart_dialog->exec(&edit_cart,RDCart::All,&edit_svcname,1)==0) {
+  if(edit_cart_dialog->exec(&edit_cart,RDCart::All,&edit_svcname,1,
+			    edit_user_name,edit_user_password)==0) {
     DisplayCart(edit_cart);
   }
 }
@@ -198,8 +190,13 @@ void RDButtonDialog::clearCartData()
 
 void RDButtonDialog::setColorData()
 {
-  edit_color=QColorDialog::getColor(edit_color,this,"edit_color_dialog");
-  edit_color_button->setPalette(QPalette(edit_color,backgroundColor()));
+  QColor new_color=QColorDialog::getColor(edit_color,this,"edit_color_dialog");
+  if(new_color.isValid()) {
+    edit_color=new_color;
+    QPalette p=QPalette(edit_color,backgroundColor());
+    p.setColor(QColorGroup::ButtonText,RDGetTextColor(edit_color));
+    edit_color_button->setPalette(p);
+  }
 }
 
 
@@ -238,23 +235,28 @@ void RDButtonDialog::cancelData()
 
 void RDButtonDialog::DisplayCart(int cartnum)
 {
-  QString str;
-
   if(cartnum==0) {
     edit_cart_edit->setText("");
     return;
   }
   RDCart *cart=new RDCart((unsigned)cartnum);
   if(cart->exists()) {
+    edit_cart_edit->
+      setText(QString().sprintf("%06u - ",cart->number())+cart->title());
+    /*
     edit_cart_edit->setText(QString().sprintf("%06u - %s",
 					      cart->number(),
 					      (const char *)cart->title()));
+    */
   }
   else {
-    str=QString(tr("NOT FOUND"));
+    edit_cart_edit->setText(QString().sprintf("%06u - [",cart->number())+"] "+
+			    tr("NOT FOUND"));
+    /*
     edit_cart_edit->
       setText(QString().sprintf("%06u - [%s]",cart->number(),
 				(const char *)str));
+    */
   }
   delete cart;
 }
