@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdedit_audio.cpp,v 1.26.6.1 2012/05/07 23:31:59 cvs Exp $
+//      $Id: rdedit_audio.cpp,v 1.26.6.3 2014/01/16 02:44:59 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -35,13 +35,15 @@
 #include <rdtrimaudio.h>
 
 RDEditAudio::RDEditAudio(RDCart *cart,QString cut_name,RDCae *cae,RDUser *user,
-			 RDStation *station,int card,int port,int preroll,
+			 RDStation *station,RDConfig *config,int card,
+			 int port,int preroll,
 			 int trim_level,QWidget *parent,const char *name)
   : QDialog(parent,name,true)
 {
   edit_cae=cae;
   edit_station=station;
   edit_user=user;
+  edit_config=config;
   edit_card=card;
   edit_port=port;
   edit_stream=-1;
@@ -99,8 +101,7 @@ RDEditAudio::RDEditAudio(RDCart *cart,QString cut_name,RDCae *cae,RDUser *user,
   // The Cut
   //
   edit_cut=new RDCut(cut_name);
-  setCaption(QString().sprintf("Edit Markers - %s\n",
-			       (const char *)edit_cut->description()));
+  setCaption("RDLibrary - "+tr("Edit Audio"));
 
   //
   // The Audio
@@ -111,7 +112,7 @@ RDEditAudio::RDEditAudio(RDCart *cart,QString cut_name,RDCae *cae,RDUser *user,
 	  this,SLOT(positionData(int,unsigned)));
   edit_cae->loadPlay(edit_card,edit_cut->cutName(),&edit_stream,&edit_handle);
   RDSetMixerOutputPort(edit_cae,edit_card,edit_stream,edit_port);
-  RDAudioInfo *info=new RDAudioInfo(station,this);
+  RDAudioInfo *info=new RDAudioInfo(station,edit_config,this);
   RDAudioInfo::ErrorCode audio_err;
   info->setCartNumber(RDCut::cartNumber(cut_name));
   info->setCutNumber(RDCut::cutNumber(cut_name));
@@ -773,7 +774,7 @@ RDEditAudio::RDEditAudio(RDCart *cart,QString cut_name,RDCae *cae,RDUser *user,
   //
   // The Wave Forms
   //
-  edit_peaks=new RDPeaksExport(station,this);
+  edit_peaks=new RDPeaksExport(station,config,this);
   RDPeaksExport::ErrorCode conv_err;
   edit_peaks->setCartNumber(RDCut::cartNumber(cut_name));
   edit_peaks->setCutNumber(RDCut::cutNumber(cut_name));
@@ -1527,20 +1528,20 @@ void RDEditAudio::trimHeadData()
 {
   RDEditAudio::CuePoints point;
   RDTrimAudio::ErrorCode conv_err;
-  RDTrimAudio *conv=new RDTrimAudio(edit_station,this);
+  RDTrimAudio *conv=new RDTrimAudio(edit_station,edit_config,this);
   conv->setCartNumber(edit_cut->cartNumber());
   conv->setCutNumber(edit_cut->cutNumber());
   conv->setTrimLevel(100*edit_trim_box->value());
   switch(conv_err=conv->runTrim(edit_user->name(),edit_user->password())) {
   case RDTrimAudio::ErrorOk:
     if(conv->startPoint()>=0) {
-    point=edit_cue_point;
-    edit_cue_point=RDEditAudio::Start;
-    PositionCursor((double)conv->startPoint()*(double)edit_sample_rate/1000.0);
-    UpdateCounters();
-    edit_cue_point=point;
-  }
-
+      point=edit_cue_point;
+      edit_cue_point=RDEditAudio::Start;
+      PositionCursor((double)conv->startPoint()*
+		     (double)edit_sample_rate/1000.0);
+      UpdateCounters();
+      edit_cue_point=point;
+    }
     break;
 
   default:
@@ -1556,20 +1557,19 @@ void RDEditAudio::trimTailData()
 {
   RDEditAudio::CuePoints point;
   RDTrimAudio::ErrorCode conv_err;
-  RDTrimAudio *conv=new RDTrimAudio(edit_station,this);
+  RDTrimAudio *conv=new RDTrimAudio(edit_station,edit_config,this);
   conv->setCartNumber(edit_cut->cartNumber());
   conv->setCutNumber(edit_cut->cutNumber());
   conv->setTrimLevel(100*edit_trim_box->value());
   switch(conv_err=conv->runTrim(edit_user->name(),edit_user->password())) {
   case RDTrimAudio::ErrorOk:
     if(conv->endPoint()>=0) {
-    point=edit_cue_point;
-    edit_cue_point=RDEditAudio::End;
-    PositionCursor((double)conv->endPoint()*(double)edit_sample_rate/1000.0);
-    UpdateCounters();
-    edit_cue_point=point;
-  }
-
+      point=edit_cue_point;
+      edit_cue_point=RDEditAudio::End;
+      PositionCursor((double)conv->endPoint()*(double)edit_sample_rate/1000.0);
+      UpdateCounters();
+      edit_cue_point=point;
+    }
     break;
 
   default:
