@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdlog_line.cpp,v 1.107.2.4 2009/11/17 17:45:53 cvs Exp $
+//      $Id: rdlog_line.cpp,v 1.113.4.13.2.2 2014/05/22 16:12:54 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -24,13 +24,15 @@
 #include <syslog.h>
 #endif  // WIN32
 
+#include <qobject.h>
+
 #include <rddb.h>
 #include <rdconf.h>
 #include <rd.h>
 #include <rdlog_line.h>
 #include <rdcut.h>
 #include <rdmacro_event.h>
-
+#include <rdweb.h>
 
 RDLogLine::RDLogLine()
 {
@@ -46,7 +48,7 @@ RDLogLine::RDLogLine(unsigned cartnum)
   clear();
   log_cart_number=cartnum;
   sql=QString().sprintf("select GROUP_NAME,TITLE,ARTIST,ALBUM,YEAR,LABEL,\
-                         CLIENT,AGENCY,COMPOSER,PUBLISHER,USER_DEFINED \
+                         CLIENT,AGENCY,COMPOSER,PUBLISHER,USER_DEFINED,NOTES \
                          from CART where NUMBER=%u",log_cart_number);
   q=new RDSqlQuery(sql);
   if(q->first()) {
@@ -61,6 +63,7 @@ RDLogLine::RDLogLine(unsigned cartnum)
     log_composer=q->value(8).toString();
     log_publisher=q->value(9).toString();
     log_user_defined=q->value(10).toString();
+    log_cart_notes=q->value(11).toString();
   }
   delete q;
 }
@@ -96,6 +99,7 @@ void RDLogLine::clear()
   log_fadeup_gain=0;
   log_duck_up_gain=0;
   log_duck_down_gain=0;
+  log_hook_mode=false;
   log_hook_start=-1;
   log_hook_end=-1;
   log_cart_type=RDCart::Audio;
@@ -108,11 +112,14 @@ void RDLogLine::clear()
   log_isrc="";
   log_album="";
   log_year=QDate();
-  log_isrc="";
+  log_isci="";
   log_label="";
+  log_conductor="";
+  log_song_id="";
   log_client="";
   log_agency="";
   log_outcue="";
+  log_description="";
   log_user_defined="";
   log_usage_code=RDCart::UsageFeature;
   log_forced_length=0;
@@ -157,6 +164,8 @@ void RDLogLine::clear()
   log_cut_name="";
   log_average_segue_length=0;
   log_has_custom_transition=false;
+  log_use_event_length=false;
+  log_event_length=-1;
   log_link_event_name="";
   log_link_start_time=QTime();
   log_link_length=0;
@@ -247,6 +256,9 @@ RDCart::Validity RDLogLine::validity(const QDateTime &datetime) const
   if(datetime>log_end_datetime) {
     return RDCart::NeverValid;
   }
+  if(datetime<log_start_datetime) {
+    return RDCart::FutureValid;
+  }
   return log_validity;
 }
 
@@ -618,6 +630,18 @@ void RDLogLine::setTalkEndPoint(int point)
 }
 
 
+bool RDLogLine::hookMode() const
+{
+  return log_hook_mode;
+}
+
+
+void RDLogLine::setHookMode(bool state)
+{
+  log_hook_mode=state;
+}
+
+
 int RDLogLine::hookStartPoint() const
 {
   return log_hook_start;
@@ -774,6 +798,18 @@ void RDLogLine::setIsrc(const QString &string)
 }
 
 
+QString RDLogLine::isci() const
+{
+  return log_isci;
+}
+
+
+void RDLogLine::setIsci(const QString &string)
+{
+  log_isci=string;
+}
+
+
 QString RDLogLine::label() const
 {
   return log_label;
@@ -786,6 +822,30 @@ void RDLogLine::setLabel(const QString &label)
 }
 
 
+QString RDLogLine::conductor() const
+{
+  return log_conductor;
+}
+
+
+void RDLogLine::setConductor(const QString &cond)
+{
+  log_conductor=cond;
+}
+
+
+QString RDLogLine::songId() const
+{
+  return log_song_id;
+}
+
+
+void RDLogLine::setSongId(const QString &id)
+{
+  log_song_id=id;
+}
+
+
 QString RDLogLine::client() const
 {
   return log_client;
@@ -822,6 +882,18 @@ void RDLogLine::setOutcue(const QString &outcue)
 }
 
 
+QString RDLogLine::description() const
+{
+  return log_description;
+}
+
+
+void RDLogLine::setDescription(const QString &desc)
+{
+  log_description=desc;
+}
+
+
 QString RDLogLine::userDefined() const
 {
   return log_user_defined;
@@ -834,6 +906,18 @@ void RDLogLine::setUserDefined(const QString &string)
 }
 
 
+QString RDLogLine::cartNotes() const
+{
+  return log_cart_notes;
+}
+
+
+void RDLogLine::setCartNotes(const QString &str)
+{
+  log_cart_notes=str;
+}
+
+
 RDCart::UsageCode RDLogLine::usageCode() const
 {
   return log_usage_code;
@@ -1310,6 +1394,30 @@ void RDLogLine::setNowNextEnabled(bool state)
 }
 
 
+bool RDLogLine::useEventLength() const
+{
+  return log_use_event_length;
+}
+
+
+void RDLogLine::setUseEventLength(bool state)
+{
+  log_use_event_length=state;
+}
+
+
+int RDLogLine::eventLength() const
+{
+  return log_event_length;
+}
+
+
+void RDLogLine::setEventLength(int msec)
+{
+  log_event_length=msec;
+}
+
+
 QString RDLogLine::linkEventName() const
 {
   return log_link_event_name;
@@ -1416,6 +1524,8 @@ QString RDLogLine::resolveWildcards(QString pattern)
   pattern.replace("%l",album());
   pattern.replace("%y",year().toString("yyyy"));
   pattern.replace("%b",label());
+  pattern.replace("%r",conductor());
+  pattern.replace("%s",songId());
   pattern.replace("%c",client());
   pattern.replace("%e",agency());
   pattern.replace("%m",composer());
@@ -1427,13 +1537,13 @@ QString RDLogLine::resolveWildcards(QString pattern)
 
 
 RDLogLine::State RDLogLine::setEvent(int mach,RDLogLine::TransType next_type,
-				      bool timescale)
+				     bool timescale,int len)
 {
   RDCart *cart;
   RDMacroEvent *rml_event;
   QString sql;
   RDSqlQuery *q;
-  double time_ratio;
+  double time_ratio=1.0;
 
   switch(log_type) {
       case RDLogLine::Cart:
@@ -1461,7 +1571,7 @@ RDLogLine::State RDLogLine::setEvent(int mach,RDLogLine::TransType next_type,
 			       SEGUE_GAIN,\
                                TALK_START_POINT,TALK_END_POINT,\
                                HOOK_START_POINT,HOOK_END_POINT,\
-                               OUTCUE,ISRC from CUTS\
+                               OUTCUE,ISRC,ISCI,DESCRIPTION from CUTS\
                                where CUT_NAME=\"%s\"",
 			      (const char *)log_cut_name);
 	q=new RDSqlQuery(sql);
@@ -1484,12 +1594,27 @@ RDLogLine::State RDLogLine::setEvent(int mach,RDLogLine::TransType next_type,
 	  return RDLogLine::NoCut;
 	}
 	if(timescale) {
-	  log_effective_length=cart->forcedLength();
-	  time_ratio=(double)log_forced_length/
-	    (q->value(2).toDouble()-q->value(1).toDouble());
-	  if(((1.0/time_ratio)<RD_TIMESCALE_MIN)||
-	     ((1.0/time_ratio)>RD_TIMESCALE_MAX)) {
-	    timescale=false;
+	  if(len>0) {
+	    log_effective_length=len;
+	    log_forced_length=len;
+	  }
+	  else {
+	    if(log_hook_mode&&
+	       (q->value(8).toInt()>=0)&&(q->value(9).toInt()>=0)) {
+	      log_effective_length=q->value(9).toInt()-q->value(8).toInt();
+	      log_forced_length=log_effective_length;
+	      time_ratio=1.0;
+	      timescale=false;
+	    }
+	    else {
+	      log_effective_length=cart->forcedLength();
+	      time_ratio=(double)log_forced_length/
+		(q->value(2).toDouble()-q->value(1).toDouble());
+	      if(((1.0/time_ratio)<RD_TIMESCALE_MIN)||
+		 ((1.0/time_ratio)>RD_TIMESCALE_MAX)) {
+		timescale=false;
+	      }
+	    }
 	  }
 	}
 	if(timescale) {
@@ -1514,20 +1639,31 @@ RDLogLine::State RDLogLine::setEvent(int mach,RDLogLine::TransType next_type,
 	  log_talk_length=log_talk_end-log_talk_start;
 	}
 	else {
-	  log_start_point[0]=q->value(1).toInt();
-	  log_end_point[0]=q->value(2).toInt();
-          if(log_start_point[RDLogLine::LogPointer]>=0 ||
-             log_end_point[RDLogLine::LogPointer]>=0) {
-            log_effective_length=log_end_point[RDLogLine::LogPointer]-
-                                   log_start_point[RDLogLine::LogPointer];
-          }
-          else {
-	    log_effective_length=q->value(0).toUInt();
-          }
-	  log_segue_start_point[0]=q->value(3).toInt();
-	  log_segue_end_point[0]=q->value(4).toInt();
-	  log_talk_start=q->value(6).toInt();
-	  log_talk_end=q->value(7).toInt();
+	  if(log_hook_mode&&
+	     (q->value(8).toInt()>=0)&&(q->value(9).toInt()>=0)) {
+	    log_start_point[0]=q->value(8).toInt();
+	    log_end_point[0]=q->value(9).toInt();
+	    log_segue_start_point[0]=-1;
+	    log_segue_end_point[0]=-1;
+	    log_talk_start=-1;
+	    log_talk_end=-1;
+	  }
+	  else {
+	    log_start_point[0]=q->value(1).toInt();
+	    log_end_point[0]=q->value(2).toInt();
+	    if(log_start_point[RDLogLine::LogPointer]>=0 ||
+	       log_end_point[RDLogLine::LogPointer]>=0) {
+	      log_effective_length=log_end_point[RDLogLine::LogPointer]-
+		log_start_point[RDLogLine::LogPointer];
+	    }
+	    else {
+	      log_effective_length=q->value(0).toUInt();
+	    }
+	    log_segue_start_point[0]=q->value(3).toInt();
+	    log_segue_end_point[0]=q->value(4).toInt();
+	    log_talk_start=q->value(6).toInt();
+	    log_talk_end=q->value(7).toInt();
+	  }
 	  log_hook_start=q->value(8).toInt();
 	  log_hook_end=q->value(9).toInt();
           if(log_talk_end>log_end_point[RDLogLine::LogPointer] && 
@@ -1560,6 +1696,8 @@ RDLogLine::State RDLogLine::setEvent(int mach,RDLogLine::TransType next_type,
 	}
 	log_outcue=q->value(10).toString();
 	log_isrc=q->value(11).toString();
+	log_isci=q->value(12).toString();
+	log_description=q->value(13).toString();
 	log_segue_gain_cut=q->value(5).toInt();
 	delete q;
 	delete cart;
@@ -1616,19 +1754,21 @@ RDLogLine::State RDLogLine::setEvent(int mach,RDLogLine::TransType next_type,
 
 
 void RDLogLine::loadCart(int cartnum,RDLogLine::TransType next_type,int mach,
-			 bool timescale,RDLogLine::TransType type)
+			 bool timescale,RDLogLine::TransType type,int len)
 {
   QString sql=QString().sprintf("select CART.TYPE,CART.GROUP_NAME,CART.TITLE,\
                                  CART.ARTIST,CART.ALBUM,CART.YEAR,CART.ISRC,\
                                  CART.LABEL,CART.CLIENT,CART.AGENCY,\
-                                 CART.USER_DEFINED,CART.FORCED_LENGTH,\
+                                 CART.USER_DEFINED,CART.CONDUCTOR,CART.SONG_ID,\
+                                 CART.FORCED_LENGTH,\
                                  CART.CUT_QUANTITY,CART.LAST_CUT_PLAYED,\
                                  CART.PLAY_ORDER,CART.START_DATETIME,\
                                  CART.END_DATETIME,CART.ENFORCE_LENGTH,\
                                  CART.PRESERVE_PITCH,GROUPS.ENABLE_NOW_NEXT,\
                                  CART.ASYNCRONOUS,CART.PUBLISHER,\
                                  CART.COMPOSER,CART.USAGE_CODE,\
-                                 CART.AVERAGE_SEGUE_LENGTH,GROUPS.COLOR \
+                                 CART.AVERAGE_SEGUE_LENGTH,CART.NOTES,\
+                                 GROUPS.COLOR \
                                  from CART left join GROUPS on\
                                  CART.GROUP_NAME=GROUPS.NAME\
                                  where (CART.NUMBER=%d)",
@@ -1663,21 +1803,30 @@ void RDLogLine::loadCart(int cartnum,RDLogLine::TransType next_type,int mach,
   log_client=q->value(8).toString();
   log_agency=q->value(9).toString();
   log_user_defined=q->value(10).toString();
-  log_forced_length=q->value(11).toUInt();
-  log_cut_quantity=q->value(12).toUInt();
-  log_last_cut_played=q->value(13).toUInt();
-  log_play_order=(RDCart::PlayOrder)q->value(14).toInt();
-  log_start_datetime=q->value(15).toDateTime();
-  log_end_datetime=q->value(16).toDateTime();
-  log_preserve_pitch=RDBool(q->value(18).toString());
-  log_enforce_length=RDBool(q->value(17).toString());
-  log_now_next_enabled=RDBool(q->value(19).toString());
-  log_asyncronous=RDBool(q->value(20).toString());
-  log_publisher=q->value(21).toString();
-  log_composer=q->value(22).toString();
-  log_usage_code=(RDCart::UsageCode)q->value(23).toInt();
-  log_average_segue_length=q->value(24).toInt();
-  log_group_color=QColor(q->value(25).toString());
+  log_conductor=q->value(11).toString();
+  log_song_id=q->value(12).toString();
+  log_cut_quantity=q->value(14).toUInt();
+  log_last_cut_played=q->value(15).toUInt();
+  log_play_order=(RDCart::PlayOrder)q->value(16).toInt();
+  log_start_datetime=q->value(17).toDateTime();
+  log_end_datetime=q->value(18).toDateTime();
+  log_preserve_pitch=RDBool(q->value(20).toString());
+  if(len<0) {
+    log_forced_length=q->value(13).toUInt();
+    log_enforce_length=RDBool(q->value(19).toString());
+  }
+  else {
+    log_forced_length=len;
+    log_enforce_length=true;
+  }
+  log_now_next_enabled=RDBool(q->value(21).toString());
+  log_asyncronous=RDBool(q->value(22).toString());
+  log_publisher=q->value(23).toString();
+  log_composer=q->value(24).toString();
+  log_usage_code=(RDCart::UsageCode)q->value(25).toInt();
+  log_average_segue_length=q->value(26).toInt();
+  log_cart_notes=q->value(27).toString();
+  log_group_color=QColor(q->value(28).toString());
   log_play_source=RDLogLine::UnknownSource;
   if(type!=RDLogLine::NoTrans) {
     log_trans_type=type;
@@ -1721,6 +1870,98 @@ void RDLogLine::refreshPointers()
 }
 
 
+QString RDLogLine::xml(int line) const
+{
+  QString ret;
+#ifndef WIN32
+  ret+="  <logLine>\n";
+  ret+="    "+RDXmlField("line",line);
+  ret+="    "+RDXmlField("id",id());
+  ret+="    "+RDXmlField("type",RDLogLine::typeText(type()));
+  ret+="    "+RDXmlField("cartType",RDCart::typeText(cartType()));
+  ret+="    "+RDXmlField("cartNumber",cartNumber());
+  ret+="    "+RDXmlField("cutNumber",cutNumber());
+  ret+="    "+RDXmlField("groupName",groupName());
+  ret+="    "+RDXmlField("groupColor",groupColor().name());
+  ret+="    "+RDXmlField("title",title());
+  ret+="    "+RDXmlField("artist",artist());
+  ret+="    "+RDXmlField("publisher",publisher());
+  ret+="    "+RDXmlField("composer",composer());
+  ret+="    "+RDXmlField("album",album());
+  ret+="    "+RDXmlField("label",label());
+  if(year().isValid()) {
+    ret+="    "+RDXmlField("year",year().year());
+  }
+  else {
+    ret+="    "+RDXmlField("year");
+  }
+  ret+="    "+RDXmlField("client",client());
+  ret+="    "+RDXmlField("agency",agency());
+  ret+="    "+RDXmlField("userDefined",userDefined());
+  ret+="    "+RDXmlField("usageCode",usageCode());
+  ret+="    "+RDXmlField("enforceLength",enforceLength());
+  ret+="    "+RDXmlField("forcedLength",RDGetTimeLength(forcedLength(),true));
+  ret+="    "+RDXmlField("evergreen",evergreen());
+  ret+="    "+RDXmlField("source",RDLogLine::sourceText(source()));
+  ret+="    "+RDXmlField("timeType",RDLogLine::timeTypeText(timeType()));
+  if(startTime(RDLogLine::Logged).isValid()&&
+     (!startTime(RDLogLine::Logged).isNull())) {
+    ret+="    "+RDXmlField("startTime",startTime(RDLogLine::Logged).
+			   toString("hh:mm:ss.zzz"));
+  }
+  else {
+    ret+="    "+RDXmlField("startTime");
+  }
+  ret+="    "+RDXmlField("transitionType",RDLogLine::transText(transType()));
+  ret+="    "+RDXmlField("cutQuantity",cutQuantity());
+  ret+="    "+RDXmlField("lastCutPlayed",lastCutPlayed());
+  ret+="    "+RDXmlField("markerComment",markerComment());
+  ret+="    "+RDXmlField("markerLabel",markerLabel());
+
+  ret+="    "+RDXmlField("originUser",originUser());
+  ret+="    "+RDXmlField("originDateTime",originDateTime());
+  ret+="    "+RDXmlField("startPoint",startPoint(RDLogLine::CartPointer),
+			 "src=\"cart\"");
+  ret+="    "+RDXmlField("startPoint",startPoint(RDLogLine::LogPointer),
+			 "src=\"log\"");
+  ret+="    "+RDXmlField("endPoint",endPoint(RDLogLine::CartPointer),
+			 "src=\"cart\"");
+  ret+="    "+RDXmlField("endPoint",endPoint(RDLogLine::LogPointer),
+			 "src=\"log\"");
+  ret+="    "+RDXmlField("segueStartPoint",
+			 segueStartPoint(RDLogLine::CartPointer),
+			 "src=\"cart\"");
+  ret+="    "+RDXmlField("segueStartPoint",
+			 segueStartPoint(RDLogLine::LogPointer),"src=\"log\"");
+  ret+="    "+RDXmlField("segueEndPoint",
+			 segueEndPoint(RDLogLine::CartPointer),
+			 "src=\"cart\"");
+  ret+="    "+RDXmlField("segueEndPoint",
+			 segueEndPoint(RDLogLine::LogPointer),"src=\"log\"");
+  ret+="    "+RDXmlField("segueGain",segueGain());
+  ret+="    "+RDXmlField("fadeupPoint",
+			 fadeupPoint(RDLogLine::CartPointer),"src=\"cart\"");
+  ret+="    "+RDXmlField("fadeupPoint",
+			 fadeupPoint(RDLogLine::LogPointer),"src=\"log\"");
+  ret+="    "+RDXmlField("fadeupGain",fadeupGain());
+  ret+="    "+RDXmlField("fadedownPoint",
+			 fadedownPoint(RDLogLine::CartPointer),"src=\"cart\"");
+  ret+="    "+RDXmlField("fadedownPoint",
+			 fadedownPoint(RDLogLine::LogPointer),"src=\"log\"");
+  ret+="    "+RDXmlField("duckUpGain",duckUpGain());
+  ret+="    "+RDXmlField("duckDownGain",duckDownGain());
+  ret+="    "+RDXmlField("talkStartPoint",talkStartPoint());
+  ret+="    "+RDXmlField("talkEndPoint",talkEndPoint());
+  ret+="    "+RDXmlField("hookMode",hookMode());
+  ret+="    "+RDXmlField("hookStartPoint",hookStartPoint());
+  ret+="    "+RDXmlField("hookEndPoint",hookEndPoint());
+
+  ret+="  </logLine>\n";
+#endif  // WIN32
+  return ret;
+}
+
+
 QString RDLogLine::resolveWildcards(unsigned cartnum,const QString &pattern)
 {
   RDLogLine logline;
@@ -1733,27 +1974,30 @@ QString RDLogLine::startSourceText(RDLogLine::StartSource src)
 {
   switch(src) {
       case RDLogLine::StartUnknown:
-	return QT_TR_NOOP("Unknown");
+	return QObject::tr("Unknown");
 
       case RDLogLine::StartManual:
-	return QT_TR_NOOP("Manual");
+	return QObject::tr("Manual");
 
       case RDLogLine::StartPlay:
-	return QT_TR_NOOP("Play");
+	return QObject::tr("Play");
 
       case RDLogLine::StartSegue:
-	return QT_TR_NOOP("Segue");
+	return QObject::tr("Segue");
 
       case RDLogLine::StartTime:
-	return QT_TR_NOOP("Time");
+	return QObject::tr("Time");
 
       case RDLogLine::StartPanel:
-	return QT_TR_NOOP("Panel");
+	return QObject::tr("Panel");
 
       case RDLogLine::StartMacro:
-	return QT_TR_NOOP("Macro");
+	return QObject::tr("Macro");
+
+      case RDLogLine::StartChannel:
+	return QObject::tr("Channel");
   }
-  return QT_TR_NOOP("Unknown");
+  return QObject::tr("Unknown");
 }
 
 
@@ -1761,18 +2005,18 @@ QString RDLogLine::transText(RDLogLine::TransType trans)
 {
   switch(trans) {
       case RDLogLine::Play:
-	return QT_TR_NOOP("PLAY");
+	return QObject::tr("PLAY");
 
       case RDLogLine::Segue:
-	return QT_TR_NOOP("SEGUE");
+	return QObject::tr("SEGUE");
 
       case RDLogLine::Stop:
-	return QT_TR_NOOP("STOP");
+	return QObject::tr("STOP");
 
       case RDLogLine::NoTrans:
-	return QT_TR_NOOP("UNKNOWN");
+	return QObject::tr("UNKNOWN");
   }
-  return QT_TR_NOOP("UNKNOWN");
+  return QObject::tr("UNKNOWN");
 }
 
 
@@ -1780,34 +2024,52 @@ QString RDLogLine::typeText(RDLogLine::Type type)
 {
   switch(type) {
       case RDLogLine::Cart:
-	return QT_TR_NOOP("Audio");
+	return QObject::tr("Audio");
 
       case RDLogLine::Marker:
-	return QT_TR_NOOP("Marker");
+	return QObject::tr("Marker");
 
       case RDLogLine::Macro:
-	return QT_TR_NOOP("Macro");
+	return QObject::tr("Macro");
 
       case RDLogLine::OpenBracket:
-	return QT_TR_NOOP("Open Bracket");
+	return QObject::tr("Open Bracket");
 
       case RDLogLine::CloseBracket:
-	return QT_TR_NOOP("Close Bracket");
+	return QObject::tr("Close Bracket");
 
       case RDLogLine::Chain:
-	return QT_TR_NOOP("ChainTo");
+	return QObject::tr("ChainTo");
 
       case RDLogLine::Track:
-	return QT_TR_NOOP("Track");
+	return QObject::tr("Track");
 
       case RDLogLine::MusicLink:
       case RDLogLine::TrafficLink:
-	return QT_TR_NOOP("Link");
+	return QObject::tr("Link");
 
       case RDLogLine::UnknownType:
-	return QT_TR_NOOP("Unknown");
+	return QObject::tr("Unknown");
   }
-  return QT_TR_NOOP("Unknown");
+  return QObject::tr("Unknown");
+}
+
+
+QString RDLogLine::timeTypeText(RDLogLine::TimeType type)
+{
+  QString ret=QObject::tr("Unknown");
+
+  switch(type) {
+  case RDLogLine::Relative:
+    ret=QObject::tr("Relative");
+    break;
+
+  case RDLogLine::Hard:
+    ret=QObject::tr("Hard");
+    break;
+  }
+
+  return ret;
 }
 
 
@@ -1815,19 +2077,19 @@ QString RDLogLine::sourceText(RDLogLine::Source src)
 {
   switch(src) {
       case RDLogLine::Manual:
-	return QT_TR_NOOP("Manual");
+	return QObject::tr("Manual");
 
       case RDLogLine::Traffic:
-	return QT_TR_NOOP("Traffic");
+	return QObject::tr("Traffic");
 
       case RDLogLine::Music:
-	return QT_TR_NOOP("Music");
+	return QObject::tr("Music");
 
       case RDLogLine::Template:
-	return QT_TR_NOOP("RDLogManager");
+	return QObject::tr("RDLogManager");
 
       case RDLogLine::Tracker:
-	return QT_TR_NOOP("Tracker");
+	return QObject::tr("Tracker");
   }
-  return QT_TR_NOOP("Unknown");
+  return QObject::tr("Unknown");
 }
