@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: stop_counter.cpp,v 1.16 2007/09/08 17:20:52 dmills Exp $
+//      $Id: stop_counter.cpp,v 1.21 2011/01/10 19:27:40 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,7 +20,7 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#include <qbitmap.h>
+#include <qpixmap.h>
 #include <qpainter.h>
 
 #include <stop_counter.h>
@@ -135,11 +135,14 @@ void StopCounter::UpdateTime()
     addMSecs(rdstation_conf->timeOffset()).msecsTo(stop_time);
 
   if ((old_stop_running != stop_running) || (msecs/1000 != old_msecs/1000)){
-	  QBitmap pix(sizeHint().width(),sizeHint().height());
+	  QPixmap pix(sizeHint().width(),sizeHint().height());
 	  QPainter *p=new QPainter(&pix);
 	  old_stop_running = stop_running;
 	  old_msecs = msecs;
-	  p->eraseRect(0,0,sizeHint().width(),sizeHint().height());
+	  
+	  p->fillRect(0,0,sizeHint().width(),sizeHint().height(),
+		      backgroundColor());
+	  //p->eraseRect(0,0,sizeHint().width(),sizeHint().height());
 	  p->setPen(QColor(color1));
 	  p->setFont(stop_text_font);
 	  p->drawText((sizeHint().width()-p->fontMetrics().width(stop_text))/2,22,
