@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004,2008 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_event.cpp,v 1.53 2012/02/20 16:44:53 cvs Exp $
+//      $Id: edit_event.cpp,v 1.53.2.4.2.1 2014/06/24 18:27:06 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -150,11 +150,7 @@ EditEvent::EditEvent(QString eventname,bool new_event,
   // Cart List
   //
   event_lib_list=new LibListView(this,"event_lib_list");
-#ifdef WIN32
-  event_lib_list->setGeometry(10,80,CENTER_LINE-20,sizeHint().height()-250);
-#else
   event_lib_list->setGeometry(10,80,CENTER_LINE-20,sizeHint().height()-300);
-#endif  // WIN32
   event_lib_list->setAllColumnsShowFocus(true);
   event_lib_list->setItemMargin(5);
   event_lib_list->addColumn("");
@@ -170,6 +166,12 @@ EditEvent::EditEvent(QString eventname,bool new_event,
   connect(event_lib_list,SIGNAL(clicked(QListViewItem *)),
 	  this,SLOT(cartClickedData(QListViewItem *)));
   
+  //
+  // Empty Cart Source
+  //
+  event_empty_cart=new RDEmptyCart(this);
+  event_empty_cart->setGeometry(CENTER_LINE-227,sizeHint().height()-202,32,32);
+
   //
   // Cart Player
   //
@@ -1116,7 +1118,6 @@ void EditEvent::preimportDownData()
 {
   int line;
   QListViewItem *item=event_preimport_list->selectedItem();
-  printf("HERE: %p\n",item);
   if(item==NULL) {
     return;
   }
@@ -1324,8 +1325,8 @@ void EditEvent::RefreshLibrary()
   sql+=QString().
     sprintf(" where %s && %s",
 	    (const char *)
-	    RDCartSearchText(event_lib_filter_edit->text(),group,"").utf8(),
-	    (const char *)type_filter);
+	    RDCartSearchText(event_lib_filter_edit->text(),group,"",false).
+	    utf8(),(const char *)type_filter);
   RDSqlQuery *q=new RDSqlQuery(sql);
   QListViewItem *item;
   event_lib_list->clear();
@@ -1663,13 +1664,10 @@ void EditEvent::AbandonEvent(QString name)
 			(const char *)RDEscapeString(name));
   q=new RDSqlQuery(sql);
   delete q;
-  name.replace(" ","_");
-  sql=QString().sprintf("drop table %s_PRE",
-			(const char *)RDEscapeStringSQLColumn(name));
+  sql=QString("drop table `")+RDEvent::preimportTableName(name)+"`";
   q=new RDSqlQuery(sql);
   delete q;
-  sql=QString().sprintf("drop table %s_POST",
-			(const char *)RDEscapeStringSQLColumn(name));
+  sql=QString("drop table `")+RDEvent::postimportTableName(name)+"`";
   q=new RDSqlQuery(sql);
   delete q;
 }
